Learn R Programming

radiomics (version 0.1.3)

mglszm: Multiple gray level size zone matrix.

Description

mglszm returns a matrix of class "mglszm", the multiple gray level size zone matrix for a given matrix.

Usage

mglszm(data, truncate = TRUE, ...)

Arguments

data

A 2D image matrix.

truncate

Logical, removes any sizes or gray levels that have no entries.

...

Can be given verbose=FALSE to suppress output from the n_grey conversion.

Value

a matrix of dimension n_grey by region size, the MGLSZM. The column names represent the region size, row names represent grey level, and the entries represent the count of how many times a given size of given grey level occur.

Details

The function creates a GLSZM using grey levels: 2, 4, 8, 16, 32, 64, 128, and 256. The values of these GLSZM's are then weighted and combined using a gaussian distribution with mean of 0 and sd of 1.

Can be visualized using image(mglszm(data)). For visualization info see ?image.radiomics

References

http://thibault.biz/Research/ThibaultMatrices/MGLSZM/MGLSZM.html

Examples

Run this code
# NOT RUN {
image(psf)
mglszm(psf)

image(discretizeImage(psf, n_grey=5, verbose=F))
mglszm(psf, n_grey=5, verbose=F) 
# }

Run the code above in your browser using DataLab