Learn R Programming

radiomics (version 0.1.3)

tumor: Brain Tumor Slice

Description

A Matrix of a single image slice of a tumor taken from an MRI image. This slice was extracted from one of the sample data sets of 3DSlicer.

Usage

tumor

Arguments

Format

A matrix, 47 rows by 46 columns