discretizeImage2: Image Discretization.
Description
#' discretizeImage2 Scales the grey values of an image into a specified number of values.
Usage
discretizeImage2(image, n_grey = 32)
Arguments
n_grey
The grey levels the output image will have
Details
Not currently used. Different methods of discretizing the image will be explored in the future.